aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorGravatar Fabio Bas2010-04-17 14:58:29 +0000
committerGravatar Fabio Bas2010-04-17 14:58:29 +0000
commit129e16998bf96cb59bddd44bf96be121188cd38e (patch)
tree2cecdf1d9725078d97fe96b5fa055a2ef403dab8
parentadded doxygen doc to some files of kvilib and cleaned some typos (diff)
downloadKVIrc-129e16998bf96cb59bddd44bf96be121188cd38e.tar.gz
KVIrc-129e16998bf96cb59bddd44bf96be121188cd38e.tar.bz2
KVIrc-129e16998bf96cb59bddd44bf96be121188cd38e.zip
some doc/pic updates
git-svn-id: https://svn.kvirc.de/svn/trunk/kvirc@4254 17fca916-40b9-46aa-a4ea-0a15b648b75c
-rw-r--r--ChangeLog21
-rw-r--r--cmake/KVIrc.nsi.cmake6
-rw-r--r--data/pics/kvi_splash.pngbin210890 -> 202409 bytes
-rw-r--r--win32build/README.txt1
4 files changed, 23 insertions, 5 deletions
diff --git a/ChangeLog b/ChangeLog
index ad9c09356..0d442e55d 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -2,6 +2,21 @@ This is KVIrc's changelog. It tipically lists new added features and changes tha
kvirc's previous behaviour. For a more detailed (and up to date) log, point your browser at:
https://svn.kvirc.de/kvirc/timeline
+April 2010
+ [CtrlAltCa]
+ - added text to dcc video
+ - moved the "smart nick colors" functions to their own file and added the ability to expose your current personalized nick colors to others
+
+March 2010
+ [Pragma]
+ - Make the default script translatable again. This time in its own set of po
+ [Noldor]
+ - Improved the logview module
+ [Noldor and HelLViS69]
+ - Improvements in theme manager
+ [CtrlAltCa]
+ - Ported the old scripts to kvirc4's kvs
+ - added $uflags()
February 2010
[CtrlAltCa]
@@ -11,9 +26,13 @@ February 2010
full support for +q (quiet ban) mode
- added support for CAP (extended capabilities)
- added support for SASL (plain and dh-blowfish methods)
+ - Readded the theme choice on first setup
[Noldor]
- Rewrote the aliaseditor module
-
+ - kvirc theme manager script
+ - Created classeditor module
+ [HelLViS69]
+ - Readded the ability to customize CTCP version reply
January 2010
[CtrlAltCa]
diff --git a/data/pics/kvi_splash.png b/data/pics/kvi_splash.png
index 1fc66a1d2..f358087b4 100644
--- a/data/pics/kvi_splash.png
+++ b/data/pics/kvi_splash.png
Binary files differ
diff --git a/win32build/README.txt b/win32build/README.txt
deleted file mode 100644
index 8a491affd..000000000
--- a/win32build/README.txt
+++ /dev/null
@@ -1 +0,0 @@
-lll
diff --git a/cmake/KVIrc.nsi.cmake b/cmake/KVIrc.nsi.cmake
index f367ea673..f18327a7d 100644
--- a/cmake/KVIrc.nsi.cmake
+++ b/cmake/KVIrc.nsi.cmake
@@ -6,7 +6,7 @@
!include "LogicLib.nsh"
Name "KVIrc"
-!define VERSION '4.0.0-rc2'
+!define VERSION '4.0.0-rc3'
!define RELEASE_NAME 'Insomnia (wip)'
!define /date RELEASE_VERSION 'r@CMAKE_KVIRC_BUILD_REVISION@'
!define URL_ABOUT 'http://www.kvirc.net/'
@@ -14,8 +14,8 @@ Name "KVIrc"
!define URL_UPDATE 'http://www.kvirc.net/'
!define PUBLISHER 'Szymon Stefanek and The KVIrc Development Team'
-; Svn release, eg: KVIrc-4.0.0-rc2-dev-r3700.exe
-OutFile KVIrc-${VERSION}-dev-${RELEASE_VERSION}.exe
+; Svn release, eg: KVIrc-4.0.0-rc3-dev-r4300.exe
+OutFile KVIrc-${VERSION}-${RELEASE_VERSION}-dev.exe
; Stable version, eg: KVIrc-4.0.0-Insomnia.exe
;OutFile KVIrc-${VERSION}-${RELEASE_NAME}.exe